/*!
 * rollup-plugin-json5 v1.0.0
 *
 * @author Allex Wang <allex.wxn@gmail.com>
 * Released under the MIT License.
 */
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var JSON5 = _interopDefault(require('json5'));
var rollupPluginutils = require('rollup-pluginutils');

function json() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var filter = rollupPluginutils.createFilter(options.include, options.exclude);
  var indent = 'indent' in options ? options.indent : '\t';
  var test = options.test || function (id) {
    return (/\.(json|babelrc)$/.test(id)
    );
  };

  return {
    name: 'json5',

    transform: function transform(json, id) {
      if (!test(id) || !filter(id)) {
        return null;
      }

      var data = JSON5.parse(json);
      if (Object.prototype.toString.call(data) !== '[object Object]') {
        return { code: 'export default ' + json + ';\n', map: { mappings: '' } };
      }

      return {
        code: rollupPluginutils.dataToEsm(data, { preferConst: options.preferConst, indent: indent }),
        map: { mappings: '' }
      };
    }
  };
}

module.exports = json;
